@@ -1,22 +1,27 @@
 package OpenInteract::Config::IniFile;
 
-# $Id: IniFile.pm,v 1.2 2001/10/17 04:48:58 lachoy Exp $
+# $Id: IniFile.pm,v 1.4 2002/04/22 05:05:17 lachoy Exp $
 
 use strict;
 use OpenInteract::Config qw( _w DEBUG );
 use OpenInteract::Config::Ini;
 
 @OpenInteract::Config::IniFile::ISA     = qw( OpenInteract::Config );
-$OpenInteract::Config::IniFile::VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Config::IniFile::VERSION = substr(q$Revision: 1.4 $, 10);
 
 use constant META_KEY => '_INI';
 
+sub valid_keys {
+    my ( $self ) = @_;
+    return $self->sections;
+    #return grep ! /^_/, keys %{ $self };
+}
+
 
 sub read_config {
     my ( $class, $filename ) = @_;
     $class->is_file_valid( $filename );
-    my $ini = OpenInteract::Config::Ini->new({ filename => $filename });
-    return $ini;
+    return OpenInteract::Config::Ini->new({ filename => $filename });
 }
 
 
