@@ -1,6 +1,6 @@
 package OpenInteract::Handler::News;
 
-# $Id: News.pm,v 1.7 2002/04/25 13:00:14 lachoy Exp $
+# $Id: News.pm,v 1.8 2002/08/25 15:51:00 lachoy Exp $
 
 use strict;
 use SPOPS::Secure qw( :level );
@@ -8,12 +8,12 @@ use Data::Dumper  qw( Dumper );
 use SPOPS::Utility;
 
 @OpenInteract::Handler::News::ISA     = qw( OpenInteract::Handler::GenericDispatcher  SPOPS::Secure );
-$OpenInteract::Handler::News::VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::News::VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::News::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::News::default_method    = 'listing';
 @OpenInteract::Handler::News::forbidden_methods = qw( _process_listing );
-%OpenInteract::Handler::News::security          = ( 
+%OpenInteract::Handler::News::security          = (
  latest  => SEC_LEVEL_READ,
  listing => SEC_LEVEL_READ,  show   => SEC_LEVEL_READ, search => SEC_LEVEL_READ,
  edit    => SEC_LEVEL_WRITE, remove => SEC_LEVEL_WRITE,
@@ -22,20 +22,21 @@ $OpenInteract::Handler::News::default_method    = 'listing';
 
 # 12 weeks -- default expiration for news item
 use constant DEFAULT_EXPIRE => 60 * 60 * 24 * 7 * 12;
-use constant MAIN_SCRIPT    => '/News';
 
 sub latest {
-    my ( $class, $p ) = @_; 
+    my ( $class, $p ) = @_;
     my $R = OpenInteract::Request->instance;
-    $p->{num_items} ||= 1;
+    my $apr = $R->apache;
 
-    my $params = { main_script => MAIN_SCRIPT,
-                   error_msg   => $p->{error_msg} };
+    my $params = { error_msg   => $p->{error_msg},
+                   show_box    => $p->{show_box} };
+    $params->{num_items} = $p->{num_items} || $apr->param( 'num_items' ) || 5;
     my $where = "active_on <= ? AND active = ? ";
     my @values = ( SPOPS::Utility->now, 'yes' );
-    my $news_list = $class->_process_listing({ where => $where,
-                                               value => \@values });
-    @{ $params->{news_list} } = splice( @{ $news_list }, 0, $p->{num_items} );
+    $params->{news_list} = $class->_process_listing({
+                                        where => $where,
+                                        value => \@values,
+                                        limit => $params->{num_items} });
     return $R->template->handler( {}, $params,
                                   { name => 'news::news_latest' } );
 }
@@ -46,15 +47,14 @@ sub latest {
 sub listing {
     my ( $class, $p ) = @_;
     my $R = OpenInteract::Request->instance;
-    my $params = { main_script => MAIN_SCRIPT,
-                   error_msg   => $p->{error_msg} };
+    my $params = { error_msg   => $p->{error_msg} };
     my $where = " active_on <= ? AND active = ? ";
     my @values = ( SPOPS::Utility->now, 'yes' );
     my $option = $R->apache->param( 'option' );
     if ( $option eq 'older' ) {
         $where .= ' AND ( expires_on < ? ) ';
     }
-    else { 
+    else {
         $where .= ' AND ( expires_on IS NULL OR expires_on > ? ) ';
     }
     push @values, SPOPS::Utility->now;
