@@ -1,14 +1,15 @@
 package OpenInteract::Handler::User;
 
-# $Id: User.pm,v 1.8 2002/01/17 17:45:22 lachoy Exp $
+# $Id: User.pm,v 1.9 2002/04/13 17:25:02 lachoy Exp $
 
 use strict;
 use Data::Dumper  qw( Dumper );
 use OpenInteract::Handler::GenericDispatcher qw( DEFAULT_SECURITY_KEY );
 use SPOPS::Secure qw( :level :scope );
+use SPOPS::Utility;
 
 @OpenInteract::Handler::User::ISA     = qw( OpenInteract::Handler::GenericDispatcher );
-$OpenInteract::Handler::User::VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::User::VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::User::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::User::default_method    = 'search_form';
@@ -195,7 +196,9 @@ sub edit {
                                   error_msg => 'Passwords do not match. Please re-enter.' });
         }
         $R->DEBUG && $R->scrib( 1, "User asked to change password. Changing." );
-        $password = $R->user->crypt_it( $password ) if ( $R->CONFIG->{login}{crypt_password} );
+        if ( $R->CONFIG->{login}{crypt_password} ) {
+            $password = SPOPS::Utility->crypt_it( $password );
+        }
         $user->{password} = $password;
         push @status, "Password changed";
     }
