@@ -1,15 +1,17 @@
 package OpenInteract::Page;
 
-# $Id: Page.pm,v 1.17 2002/01/18 22:43:00 lachoy Exp $
+# $Id: Page.pm,v 1.20 2002/01/30 17:48:15 lachoy Exp $
 
 use strict;
 use Data::Dumper   qw( Dumper );
 use File::Basename qw();
 
-$OpenInteract::Page::VERSION = sprintf("%d.%02d", q$Revision: 1.17 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Page::VERSION = sprintf("%d.%02d", q$Revision: 1.20 $ =~ /(\d+)\.(\d+)/);
 
 use constant DEFAULT_EXTENSION => '.html';
 
+sub FUNNY_CHARACTERS { return '\\\'"!#\$\%\|&\^\*\<\>{}\[\]\(\)\?' }
+
 my %STORAGE_CLASS = (
      database => 'OpenInteract::Page::Database',
      file     => 'OpenInteract::Page::File',
@@ -42,6 +44,14 @@ sub page_by_location {
 
     $location ||= '/';
 
+    # First, check if the class has 'strict_location' set and if so,
+    # just try and fetch what was passed in
+
+    if ( $class->CONFIG->{strict_location} ) {
+        return $class->fetch( $location );
+    }
+
+    # Onto the fun stuff.
     # First check to see if this is directory request that corresponds
     # to a page_directory object...
 
@@ -49,8 +59,7 @@ sub page_by_location {
         $R->DEBUG && $R->scrib( 1, "Testing [$location] as a directory" );
         my $dir = eval { $R->page_directory->fetch_by_directory( $location ) };
         if ( $@ ) {
-            my $ei = SPOPS::Error->get;
-            $R->scrib( 0, "Tried to fetch directory but got error: $ei->{system_msg}" );
+            $R->scrib( 0, "Tried to fetch directory but got error: $@" );
         }
         if ( $dir ) {
             $R->DEBUG && $R->scrib( 1, "Directory object found. Returning" );
@@ -67,28 +76,30 @@ sub page_by_location {
     push @locations, $location;
 
     my ( $extension ) = $location =~ /(\.\w+)$/;
+    my $default_extension = $class->CONFIG->{default_extension} ||
+                            DEFAULT_EXTENSION;
 
-    if ( ! $extension ) {
-        $R->DEBUG && $R->scrib( 1, "Location has no extension; add default extension" ),
-        push @locations, join( '', $location, DEFAULT_EXTENSION );
-    }
-    else {
+    if ( $extension ) {
         my ( $sans_extension );
         ( $sans_extension = $location ) =~ s/$extension$//;
         $R->DEBUG && $R->scrib( 1, "Also check location without the extension ",
-                                  "using [$sans_extension]" );
+                                   "using [$sans_extension]" );
         push @locations, $sans_extension;
     }
+    else {
+        $R->DEBUG && $R->scrib( 1, "Location has no extension; add default extension" ),
+        push @locations, join( '', $location, $default_extension );
+    }
 
     # Find things like
     #   (requested) /blah/bloo.shtml
     #   (actual)    /blah/bloo.html
 
-    if ( $extension ne DEFAULT_EXTENSION ) {
+    if ( $extension ne $default_extension ) {
         my ( $root, $other_ext ) = $location =~ m|^(.*)(\.\w+)$|;
         $R->DEBUG && $R->scrib( 1, "Extension [$extension] is not the default, also try ",
-                                   "[", DEFAULT_EXTENSION, "]" );
-        push @locations, join( '', $root, DEFAULT_EXTENSION );
+                                   "[$default_extension]" );
+        push @locations, join( '', $root, $default_extension );
     }
 
     my ( $page );
@@ -128,20 +139,47 @@ sub remove_query_string {
 }
 
 
-# Security -- remove all '.' from the beginning of the location
-# requested so people don't try to go up the directory tree. Also
-# translate any two-dot sequence to an underscore. Replace all spaces
-# with underscores. Ensure all locations begin with '/'. And finally,
-# clean the query string from the end.
+# Remove all '.' from the beginning of the name requested so
+# people don't try to go up the directory tree. Also translate any
+# two-dot sequence to an underscore. Replace all spaces with
+# underscores. Remove any 'funny characters'
+
+sub clean_name {
+    my ( $item, $name ) = @_;
+    my $class = ref $item || $item;
+    my $funny_chars = eval { $class->CONFIG->{funny_characters} } ||
+                      $class->FUNNY_CHARACTERS;
+    $name =~ s/^\.+//;
+    $name =~ s/\.\./_/g;
+    $name =~ s/\s/_/g;
+    $name =~ s/[$funny_chars]//g;
+    return $name;
+}
+
+
+# Removes all leading directories from a filename and does everything
+# in clean_location() as well. The return value should never begin
+# with a leading '/' or '\' character.
+
+sub clean_filename {
+    my ( $class, $filename ) = @_;
+    return undef unless ( $filename );
+    my $cleaned_filename = $class->clean_name( $filename );
+    $cleaned_filename =~ s|^.*/(.*)$|$1|;
+    $cleaned_filename =~ s|^.*\\(.*)$|$1|;
+    return $cleaned_filename;
+}
+
+
+# Ensure all cleaned locations begin with '/' clean the query string
+# from the end.
 
 sub clean_location {
     my ( $class, $location ) = @_;
     return undef unless ( $location );
-    $location =~ s/^\.+//;
-    $location =~ s/\.\./_/g;
-    $location =~ s/\s/_/g;
-    $location = "/$location" unless ( $location =~ m|^/| );
-    return $class->remove_query_string( $location );
+    my $cleaned = $class->clean_name( $class->remove_query_string( $location ) );
+    $cleaned = "/$cleaned" unless ( $cleaned =~ m|^/| );
+    return $cleaned;
 }
 
 
@@ -168,6 +206,53 @@ sub list_directories {
 }
 
 
+########################################
+# OBJECT METHODS
+########################################
+
+# Just replace the generated 'url' method with one that just uses the
+# location. This won't work if you do not have the Page handler
+# answering all 'unknown' requests.
+
+sub object_description {
+    my ( $self ) = @_;
+    my $info = $self->SUPER::object_description;
+    $info->{url} = $self->{location};
+    return $info;
+}
+
+
+# Fetch the content from either the filesystem or database, depending.
+
+sub fetch_content {
+    my ( $self ) = @_;
+    my $storage_class = $STORAGE_CLASS{ $self->{storage} };
+    unless ( $storage_class ) {
+        return "Cannot retrieve content -- no storage type specified";
+    }
+    return $self->{content} = $storage_class->load( $self );
+}
+
+
+# Most storage types just implement an empty method for this.
+
+sub rename_content {
+    my ( $self, $old_name ) = @_;
+    return unless ( $old_name );
+    my $storage_class = $STORAGE_CLASS{ $self->{storage} };
+    unless ( $storage_class ) {
+        die "Cannot rename content -- no storage type specified";
+    }
+    return $storage_class->rename( $self, $old_name );
+}
+
+
+sub filename_only {
+    my ( $self ) = @_;
+    return File::Basename::basename( $self->{location} );
+}
+
+
 ########################################
 # MIME STUFF
 ########################################
@@ -225,39 +310,6 @@ sub mime_type_content {
 }
 
 
-########################################
-# OBJECT METHODS
-########################################
-
-# Just replace the generated 'url' method with one that just uses the
-# location. This won't work if you do not have the Page handler
-# answering all 'unknown' requests.
-
-sub object_description {
-    my ( $self ) = @_;
-    my $info = $self->SUPER::object_description;
-    $info->{url} = $self->{location};
-    return $info;
-}
-
-
-# Fetch the content from either the filesystem or database, depending.
-
-sub fetch_content {
-    my ( $self ) = @_;
-    my $storage_class = $STORAGE_CLASS{ $self->{storage} };
-    unless ( $storage_class ) {
-        return "Cannot retrieve content -- no storage type specified";
-    }
-    return $self->{content} = $storage_class->load( $self );
-}
-
-
-sub filename_only {
-    my ( $self ) = @_;
-    return File::Basename::basename( $self->{location} );
-}
-
 ########################################
 # RULES
 ########################################
@@ -333,15 +385,78 @@ to the filesystem or in the database.
 
 =head1 METHODS
 
-B<find_directories()>
+=head2 Class Methods
 
-Class method that finds all unique directories currently used in the
-system along with the number of files in each.
+B<page_by_location( $location )>
+
+Tries to retrieve a page object with the location C<$location> from
+the database. This method goes through a number of different DWIM-my
+steps which are described below. You can turn them off by setting
+'strict_location' to a true value in your SPOPS class configuration.
+
+For the first check, we try to determine f C<$location> is a directory
+index request. Such requests either end with a '/' or do not end in an
+extension. If we find a 'page_directory' object matching C<$location>,
+we return it.
+
+Next, we start creating a list of locations to check. The first item
+in the list is C<$location>. We also put onto the list:
+
+=over 4
+
+=item * If C<$location> has an extension, we add the location without
+the extension.
+
+=item * If C<$location> has no extension, we add the location with the
+default extension. The default extension is either 'default_extension'
+from the SPOPS class configuration or the constant DEFAULT_EXTENSION
+from this class, which is 'html'.
+
+=item * If the extension for C<$location> is not the default
+extension, we add the location with the default extension rather than
+the given one.
+
+=back
+
+Then we cycle through the locations in our list. The first object we
+find gets returned.
+
+B<remove_query_string( $text )>
+
+Removes the HTTP query string from C<$text>.
+
+B<clean_name( $name )>
+
+Cleans up C<$name> by replacing any spaces and '..' sequences with
+underscores, and removing any leading '.'  characters and any 'funny'
+characters. You can define funny characters in your class
+configuration using the key 'funny_characters' or rely on the default,
+found in the package variable 'FUNNY_CHARACTERS'.
+
+B<clean_location( $location )>
+
+Does a C<clean_name()> on C<$location> and also ensures it has a
+leading '/'.
+
+B<clean_filename( $filename )>
+
+Cleans up C<$filename> so it can be used as an upload. In addition to
+running C<clean_name()> on it we also we strip any leading directories
+from the front of it.
+
+Returns: a cleaned bare filename, not in any directories.
+
+B<list_directories()>
+
+Finds all unique directories currently used by pages in the system
+along with the number of files in each.
 
 Returns an arrayref of arrayrefs. The first element in each arrayref
 in the directory name, the second is the number of files in the
 directory.
 
+=head2 Object Methods
+
 B<fetch_content()>
 
 Retrieve content for this page. Note that we do not make this a
@@ -359,6 +474,14 @@ B<filename_only()>
 
 Just return the filename portion of the full C<location> property.
 
+=head2 MIME Methods
+
+B<mime_type_by_extension( $location )>
+
+B<mime_type_file( $filename )>
+
+B<mime_type_content( $content | \$content )>
+
 =head1 RULES
 
 B<pre_save_action>
@@ -383,6 +506,10 @@ Nothing known.
 
 =head1 SEE ALSO
 
+L<File::MMagic|File::MMagic>
+
+L<File::Basename|File::Basename>
+
 =head1 COPYRIGHT
 
 Copyright (c) 2001-2002 intes.net, inc.. All rights reserved.
