@@ -1,6 +1,6 @@
 package OpenInteract::Page::Http;
 
-# $Id: Http.pm,v 1.3 2002/01/02 02:43:55 lachoy Exp $
+# $Id: Http.pm,v 1.4 2002/01/30 17:50:20 lachoy Exp $
 
 use strict;
 use HTTP::Request;
@@ -48,6 +48,14 @@ sub save {
 }
 
 
+sub rename {
+    my ( $class, $page, $old_location ) = @_;
+    warn "--Cannot rename content from [$old_location] to [$page->{location}]",
+         "since it's using HTTP storage.\n";
+    return 1;
+}
+
+
 sub remove {
     my ( $class, $page ) = @_;
     warn "--Location $page->{location} cannot be removed, since it's ",
