@@ -1,6 +1,6 @@
 package OpenInteract::PodView;
 
-# $Id: PodView.pm,v 1.4 2002/01/02 02:43:57 lachoy Exp $
+# $Id: PodView.pm,v 1.5 2002/08/25 16:54:22 lachoy Exp $
 
 use strict;
 use base qw( Pod::POM::View::HTML );
@@ -64,18 +64,20 @@ sub view_seq_link {
         $link = $2;
     }
 
-    # Now look at $link and adjust as necessary.
+    # Now look at $link and adjust as necessary, setting $href
 
-    my $href = $link;
+    my ( $href );
 
-    # Deal with http/ftp (don't do anything)
+    # Deal with http/ftp
 
     if ( $link =~ /^(http|ftp)/ ) {
+        $href = $link;
     }
 
     # Deal with email
 
     elsif ( $link =~ /^mailto:\s*(.*)\s*$/ ) {
+        $href = $link;
         $text = $1 if ( $link eq $text );
     }
 
